clion spell fixes, and a few cet retirements. (#370)
authortsteven4 <13596209+tsteven4@users.noreply.github.com>
Fri, 21 Jun 2019 13:44:52 +0000 (07:44 -0600)
committerGitHub <noreply@github.com>
Fri, 21 Jun 2019 13:44:52 +0000 (07:44 -0600)
* clion spell fixes, and a few cet retirements.

cet retirements were unused.

* more spelling fixes.

79 files changed:
arcdist.cc
bushnell.cc
cet.cc
cet.h
cet_util.h
compegps.cc
cst.cc
defs.h
discard.h
energympro.cc
exif.cc
f90g_track.cc
filter.h
garmin.cc
garmin_device_xml.h
garmin_fs.cc
garmin_gpi.cc
garmin_tables.cc
garmin_txt.cc
garmin_xt.cc
gbfile.cc
gbser.h
gbser_posix.cc
gdb.cc
globalsat_sport.cc
gopal.cc
gpsutil.cc
gpx.cc
gtm.cc
humminbird.cc
igo8.cc
internal_styles.cc
itracku.cc
jeeps/gpsapp.cc
jeeps/gpsapp.h
jeeps/gpscom.cc
jeeps/gpslibusb.cc
jeeps/gpsmath.cc
jeeps/gpsrqst.cc
jeeps/gpsserial.cc
jeeps/gpsusbcommon.cc
jeeps/jgpsutil.cc
kml.cc
lmx.cc
lowranceusr.cc
maggeo.cc
magproto.cc
main.cc
mapsource.cc
mkshort.cc
mkstyle.sh
mmo.cc
mtk_logger.cc
netstumbler.cc
nmea.cc
nmn4.cc
parse.cc
pcx.cc
position.h
reference/fugawi.notime.txt
reference/fugawi.ref.txt
reference/fugawi.time.ref.txt
reference/fugawi.time.txt
reference/track/fugawi.txt
shape.cc
skytraq.cc
src/core/xmlstreamwriter.cc
style/fugawi.style
style/xmapwpt.style
tpo.cc
trackfilter.cc
unicsv.cc
util.cc
v900.cc
vecs.cc
waypt.cc
xcsv.cc
xmlgeneric.cc
xol.cc

index db3dad48447d97304b0df7f33fb8a0967acba6fb..962fe3ad43274c827ab072f160d9faa015b6ed9d 100644 (file)
@@ -161,7 +161,7 @@ void ArcDistanceFilter::process()
         if (!arcfileopt &&
             (ed->arcpt2->altitude != unknown_alt) &&
             (ptsopt || (ed->arcpt1->altitude != unknown_alt))) {
-          /* Interpolate alititude */
+          /* Interpolate altitude */
           if (ptsopt) {
             wp->altitude = ed->arcpt2->altitude;
           } else {
index f01eb9689494b3aafa16846e330fb5f9efb9d734..c54ad36294df110b5331bdccf5d5805821476be1 100644 (file)
@@ -35,7 +35,7 @@ arglist_t bushnell_args[] = {
 };
 
 // Apparently, the icons are undocumented, so we made up names,
-// preferring them to be consistent with other brands where possiblde.
+// preferring them to be consistent with other brands where possible.
 
 typedef struct  {
   const signed int symbol;
@@ -75,7 +75,7 @@ static icon_mapping_t bushnell_icons[] = {
   { 0x19, "Blue Diamond Checkmark" }, //  undocumented.
 
   { 0x1a, "Camera" },
-  { 0x1b, "Restaraunt" }, // "Fork/Knife (meal place?)"
+  { 0x1b, "Restaurant" }, // "Fork/Knife (meal place?)"
   { 0x1c, "Restroom" }, // (man & Woman icon)"
   { 0x1d, "RV Park" }, // "Bus or RV (RV campground?)"
   { 0x1e, "Potable Water" }, // (faucet/glass or bucket)"
@@ -83,19 +83,19 @@ static icon_mapping_t bushnell_icons[] = {
   { 0x20, "Anchor in square" },
   { 0x21, "Boat ramp/launch" },
   { 0x22, "Anchor" },
-  { 0x23, "Bouy" },
+  { 0x23, "Buoy" },
   { 0x24, "Man Overboard?" },
   { 0x25, "Snow Skiing" },
-  { 0x26, "Mouantin/Mountain Peak" },
+  { 0x26, "Mountain/Mountain Peak" },
   { 0x27, "Turkey Tracks/animal tracks" },
 
-  { 0x28, "Bank" }, // "Cash (ATM MAybe)"
+  { 0x28, "Bank" }, // "Cash (ATM Maybe)"
   { 0x29, "Bar" }, // "Martini undocumented"
   { 0x2a, "Lighthouse" },
 
   { 0x2b, "Tent" },
 
-  { 0x2c, "Cresent Wrench or can opener" },
+  { 0x2c, "Crescent Wrench or can opener" },
 
   { 0x2d, "School" }, //? White Building with tunnel looking door and flag on top."
   { 0x2f, "Information" }, // "i  (info/internet maybe?)"
@@ -117,9 +117,9 @@ static icon_mapping_t bushnell_icons[] = {
   { 0x3b, "Officer? Looks like man leaned over holding blue cube..." },
   { 0x3c, "Parking" }, //"Car Parked"
   { 0x3d, "Airport" },
-  { 0x3e, "Bus Terminal" }, // (guess) Loks like Bus under canopy."
+  { 0x3e, "Bus Terminal" }, // (guess) Looks like Bus under canopy."
   { 0x3f, "Red Cross" },
-  { 0x40, "Red Buidling with flag, Fire Station maybe." },
+  { 0x40, "Red Building with flag, Fire Station maybe." },
   { 0x41, "Bus" },
   { 0x42, "Officer" }, // "see 3b: duplicate"
   { 0x43, "Railroad" },
diff --git a/cet.cc b/cet.cc
index 01e60ee27e47c564525643e07afaf4186a186181..93398a9290991cc3a0d7c820af767a22c4966ae6 100644 (file)
--- a/cet.cc
+++ b/cet.cc
@@ -31,7 +31,7 @@
 /* %%% cet_char_to_ucs4 %%%
  *
  * single character to UCS-4 code %%%
- * return values: 0 if convertable character, otherwise 1
+ * return values: 0 if convertible character, otherwise 1
  */
 
 int
@@ -194,7 +194,7 @@ cet_utf8_to_ucs4(const char* str, int* bytes, int* value)
  *
  * convert single UCS-4 value to original character from CS
  *
- * return values: coverted character or "CET_NOT_CONVERTABLE_DEFAULT"
+ * return values: converted character or "CET_NOT_CONVERTABLE_DEFAULT"
  *                if not possible
  */
 short
@@ -249,7 +249,7 @@ cet_ucs4_to_char(const int value, const cet_cs_vec_t* vec)
 
 /* %%% cet_utf8_to_char %%%
  *
- * Convert single UTF-8 sequence directly into associated characted
+ * Convert single UTF-8 sequence directly into associated characters
  * by given character set.
  */
 
diff --git a/cet.h b/cet.h
index 0d1e680b34bc4fe069bc42689650f44c3afc8a6d..ec2344d309c111302873748e334751952ffde79e 100644 (file)
--- a/cet.h
+++ b/cet.h
@@ -29,7 +29,7 @@
 
 typedef struct cet_ucs4_link_s {
   int value;                   /* UCS-4 value                  */
-  short origin;                        /* associeted character         */
+  short origin;                        /* associated character         */
 } cet_ucs4_link_t;
 
 typedef struct cet_cs_vec_s {
index 6cfb536947d60b58e255000c175a0c0ae5771a3e..f827254719e1bf4c1ef9ca5f97a812edbfcb9dc4 100644 (file)
@@ -34,16 +34,8 @@ cet_cs_vec_t* cet_find_cs_by_name(const QString& name);
 void cet_register();
 void cet_deregister();
 
-/* short hand transmissions */
-
-char* cet_str_utf8_to_cp1252(const char* src);
-char* cet_str_cp1252_to_utf8(const char* src);
 extern cet_cs_vec_t cet_cs_vec_cp1252;
 
-char* cet_str_iso8859_1_to_utf8(const char* src);
-char* cet_str_utf8_to_iso8859_1(const char* src);
-extern cet_cs_vec_t cet_cs_vec_iso8859_1;
-
 extern cet_cs_vec_t cet_cs_vec_ansi_x3_4_1968;
 
 short* cet_str_utf8_to_uni(const char* src, int* length);
index 959379a3ab7a7b5e7649983007ef27e50aa1f18f..101be2ce0de779d6fb80cd3ac02189211bdc647c 100644 (file)
@@ -23,7 +23,7 @@
     History:
                10/23/2005: First release; only a reader
                10/25/2005: becomes a writer too
-               10/26/2005: received documention from CompeGPS team
+               10/26/2005: received documentation from CompeGPS team
                            added fatals for "G" and "U" if not WGS84 and lat/lon
                08/13/2006: switch to gbfile api
 */
diff --git a/cst.cc b/cst.cc
index 890ef65ff56e73d521397ad45f2c51570304357f..8e64e1acbe64b9cce8177665c703d4bcae8930ed 100644 (file)
--- a/cst.cc
+++ b/cst.cc
@@ -262,7 +262,7 @@ cst_data_read()
                         &wpt->latitude,
                         &wpt->altitude,
                         &interp, name)) {
-          fatal(MYNAME ": Could not interprete line %d!\n", line);
+          fatal(MYNAME ": Could not interpret line %d!\n", line);
         }
 
         data_lines++;
diff --git a/defs.h b/defs.h
index 468d937e78cc222367b8db58267c84970d087112..ebfc32a3e518c4cae2292b21cab0b52ef3815664 100644 (file)
--- a/defs.h
+++ b/defs.h
@@ -203,7 +203,6 @@ extern global_options global_opts;
 extern const char gpsbabel_version[];
 extern time_t gpsbabel_now;    /* gpsbabel startup-time; initialized in main.c with time() */
 extern time_t gpsbabel_time;   /* gpsbabel startup-time; initialized in main.c with current_time(), ! ZERO within testo ! */
-extern int geocaches_present;
 
 typedef enum {
   fix_unknown=-1,
@@ -232,7 +231,7 @@ typedef enum {
   gt_virtual,
   gt_letterbox,
   gt_event,
-  gt_suprise,
+  gt_surprise,
   gt_webcam,
   gt_earth,
   gt_locationless,
@@ -420,7 +419,7 @@ public:
 };
 
 // These are dicey as they're collected on read. Subsequent filters may change
-// things, though it's u nlikely to matter in practical terms.  Don't use these
+// things, though it's unlikely to matter in practical terms.  Don't use these
 // if a false positive would be deleterious.
 #
 class global_trait
@@ -530,7 +529,7 @@ public:
    */
   int route_priority;
 
-  /* Optional dilution of precision:  positional, horizontal, veritcal.
+  /* Optional dilution of precision:  positional, horizontal, vertical.
    * 1 <= dop <= 50
    */
   float hdop;
@@ -747,10 +746,10 @@ public:
   // FIXME: Generally it is inefficient to use an element pointer or reference to define the element to be deleted, use iterator instead,
   //        and/or implement pop_back() a.k.a. removeLast(), and/or pop_front() a.k.a. removeFirst().
   void del_head(route_head* rte); // a.k.a. erase()
-  // FIXME: Generally it is inefficent to use an element pointer or reference to define the insertion point, use iterator instead.
+  // FIXME: Generally it is inefficient to use an element pointer or reference to define the insertion point, use iterator instead.
   void insert_head(route_head* rte, route_head* predecessor); // a.k.a. insert
   void add_wpt(route_head* rte, Waypoint* wpt, bool synth, const QString& namepart, int number_digits);
-  // FIXME: Generally it is inefficent to use an element pointer or reference to define the insertion point, use iterator instead.
+  // FIXME: Generally it is inefficient to use an element pointer or reference to define the insertion point, use iterator instead.
   void del_wpt(route_head* rte, Waypoint* wpt);
   void common_disp_session(const session_t* se, route_hdr rh, route_trl rt, waypt_cb wc);
   void flush(); // a.k.a. clear()
@@ -1097,7 +1096,7 @@ QString ugetenv(const char* env_var);
 
 // FIXME: case_ignore_strcmp() and case_ignore_strncmp() should probably
 // just be replaced at the call sites.  These shims are just here to make
-// them more accomidating of QString input.
+// them more accommodating of QString input.
 inline int
 case_ignore_strcmp(const QString& s1, const QString& s2)
 {
@@ -1151,12 +1150,6 @@ const QString get_filename(const QString& fname);                        /* extract the filename port
 #define CET_CHARSET_MS_ANSI    "windows-1252"
 #define CET_CHARSET_LATIN1     "ISO-8859-1"
 
-#define str_utf8_to_cp1252(str) cet_str_utf8_to_cp1252((str))
-#define str_cp1252_to_utf8(str) cet_str_cp1252_to_utf8((str))
-
-#define str_utf8_to_iso8859_1(str) cet_str_utf8_to_iso8859_1((str))
-#define str_iso8859_1_to_utf8(str) cet_str_iso8859_1_to_utf8((str))
-
 /* this lives in gpx.c */
 gpsbabel::DateTime xml_parse_time(const QString& cdatastr);
 
@@ -1170,7 +1163,7 @@ QString rot13(const QString& s);
 signed int si_round(double d);
 
 /*
- * Protypes for Endianness helpers.
+ * Prototypes for Endianness helpers.
  */
 
 signed int be_read16(const void* ptr);
index f77e86944c4c400da1d3d17a9f7d40f54df8b0a7..fca5a87cebf5c1e82f62ee2180491f51871bfcfe 100644 (file)
--- a/discard.h
+++ b/discard.h
@@ -74,11 +74,11 @@ private:
       "-1.0", ARGTYPE_END_REQ | ARGTYPE_FLOAT, ARG_NOMINMAX, nullptr
     },
     {
-      "hdopandvdop", &andopt, "Link hdop and vdop supression with AND",
+      "hdopandvdop", &andopt, "Link hdop and vdop suppression with AND",
       nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
     },
     {
-      "sat", &satopt, "Minimium sats to keep points",
+      "sat", &satopt, "Minimum sats to keep points",
       "-1.0", ARGTYPE_BEGIN_REQ | ARGTYPE_INT, ARG_NOMINMAX, nullptr
     },
     {
index d7b14c30d700b69f6b4f30cabb596988b57c681b..5f07f34985015f3d926f28c6d8f0b2cb1d0e4145 100644 (file)
@@ -145,8 +145,8 @@ read_point(route_head* gpsbabel_route,gpsbabel::DateTime& gpsDateTime)
     qDebug() << "point.lntervalTime:" << point.lntervalTime;
   }
 
-  //Time from last point in sec's * 10 (e.g. point.lntervalTime is sec multiplied witn 10)
-  // convert to milisecs
+  //Time from last point in sec's * 10 (e.g. point.lntervalTime is sec multiplied with 10)
+  // convert to millisecs
   gpsbabel::DateTime gpsbabeltime = gpsDateTime.addMSecs(point.lntervalTime*100);
   gpsDateTime.setDate(gpsbabeltime.date());
   gpsDateTime.setTime(gpsbabeltime.time());
diff --git a/exif.cc b/exif.cc
index d6b5f5856e24778f1c1d7110c7abb20defb8d7be..b76f75922bf74341434862c82195953f6becf1b6 100644 (file)
--- a/exif.cc
+++ b/exif.cc
 #define GPS_IFD_TAG_DATESTAMP 0x001D
 
 struct ExifTag {
-  uint16_t id{0};           // tag that identifieds the field.
+  uint16_t id{0};           // tag that identifies the field.
   uint16_t type{0};         // field type.
   uint32_t count{0};        // number of values. Note that Count is not the total number of bytes.
   uint32_t offset{0};       // byte offset relative to beginning of TIFF file to value (only for values longer than 4 bytes).
index 4f7d894d3c1d08384e2a945d87921a9deebe4210..6983792920f5d4ef59aa293e455a56f58da0497f 100644 (file)
@@ -22,7 +22,7 @@
 
     The map file contains a constant 30 byte header record followed by a variable number of
     TT records.  The TT records start with the two characters "TT" and are 251 bytes long.
-    The TT records conatain values for time, position and velocity.
+    The TT records contain values for time, position and velocity.
 
  */
 
index da9f43f0852094cc794bccf9b180849f1cd50dfc..d7c3aaa187588eae9da55ef400a44986aae972fe 100644 (file)
--- a/filter.h
+++ b/filter.h
@@ -31,7 +31,7 @@ public:
   // its base class type.
   // https://wiki.sei.cmu.edu/confluence/display/cplusplus/OOP52-CPP.+Do+not+delete+a+polymorphic+object+without+a+virtual+destructor
   virtual ~Filter() = default;
-  // And that requires us to explictly default the move and copy operations.
+  // And that requires us to explicitly default the move and copy operations.
   // https://github.com/isocpp/CppCoreGuidelines/blob/master/CppCoreGuidelines.md#c21-if-you-define-or-delete-any-default-operation-define-or-delete-them-all.
   Filter(const Filter&) = default;
   Filter& operator=(const Filter&) = default;
index 9280efa2e817bc2b8bb4283aca34783f0144e52c..9f5636ca09cda8cab0d316c3e3ea3107385e3958 100644 (file)
--- a/garmin.cc
+++ b/garmin.cc
@@ -709,7 +709,7 @@ lap_read_as_track(void)
 #endif
 
 /*
- * Rather than propogate Garmin-specific data types outside of the Garmin
+ * Rather than propagate Garmin-specific data types outside of the Garmin
  * code, we convert the PVT (position/velocity/time) data from the receiver
  * to the data type we use throughout.   Yes, we do lose some data that way.
  */
@@ -962,7 +962,7 @@ waypoint_prepare()
     }
     tx_waylist[i]->ident[sizeof(tx_waylist[i]->ident)-1] = 0;
 
-    // If we were explictly given a comment from GPX, use that.
+    // If we were explicitly given a comment from GPX, use that.
     //  This logic really is horrible and needs to be untangled.
     if (!wpt->description.isEmpty() &&
         global_opts.smart_names && !wpt->gc_data->diff) {
@@ -1034,7 +1034,7 @@ waypoint_write()
   int n = waypoint_prepare();
 
   if ((ret = GPS_Command_Send_Waypoint(portname, tx_waylist, n, waypt_write_cb)) < 0) {
-    fatal(MYNAME ":communication error sending wayoints..\n");
+    fatal(MYNAME ":communication error sending waypoints..\n");
   }
 
   for (int i = 0; i < n; ++i) {
index c3addcfc8ace94e65e61802803c0ed1f776fca70..0fc3770a457d66e1806cc366b18c2b7d1d327ef6 100644 (file)
@@ -48,7 +48,7 @@ const gdx_info* gdx_find_file(char** dirlist);
 
 // This is so gross.   By the time we know it's not a USB device
 // and could be one of our devices, we're so deep into the callstack
-// that can't back out tracefully without bludgeoning most of the
+// that can't back out gracefully without bludgeoning most of the
 // (Mac|Lin|Win) x (USB|Serial) matrix.   Since we don't *really* want
 // to progress any further, we just longjump back to the caller...
 #include <csetjmp>
index 46b2e5a00e3d463398cec959805003bae5f92ac7..93e0667276301a888a0705853b9dbb6b4559c6ca 100644 (file)
@@ -115,7 +115,7 @@ void garmin_fs_copy(garmin_fs_t** dest, garmin_fs_t* src)
   }
   *dest = (garmin_fs_t*) xmalloc(sizeof(*src));
 
-  /* do not copy interlinks, only increment the refrence counter */
+  /* do not copy interlinks, only increment the reference counter */
   if (src->ilinks != nullptr) {
     src->ilinks->ref_count++;
   }
index bddea7fba91ba37366934581f002f7c041e6b00e..a2060a60abf6e0f2a8a4494e6bccfb9044cb8318 100644 (file)
@@ -166,8 +166,8 @@ struct writer_data_t {
   bounds bds;
   writer_data_t* top_left{nullptr};
   writer_data_t* top_right{nullptr};
-  writer_data_t* buttom_left{nullptr};
-  writer_data_t* buttom_right{nullptr};
+  writer_data_t* bottom_left{nullptr};
+  writer_data_t* bottom_right{nullptr};
 };
 
 typedef struct gpi_waypt_data_s {
@@ -819,11 +819,11 @@ wdata_free(writer_data_t* data)
   if (data->top_right) {
     wdata_free(data->top_right);
   }
-  if (data->buttom_left) {
-    wdata_free(data->buttom_left);
+  if (data->bottom_left) {
+    wdata_free(data->bottom_left);
   }
-  if (data->buttom_right) {
-    wdata_free(data->buttom_right);
+  if (data->bottom_right) {
+    wdata_free(data->bottom_right);
   }
 
   delete data;
@@ -869,9 +869,9 @@ wdata_check(writer_data_t* data)
 
     if (wpt->latitude < center_lat) {
       if (wpt->longitude < center_lon) {
-        ref = &data->buttom_left;
+        ref = &data->bottom_left;
       } else {
-        ref = &data->buttom_right;
+        ref = &data->bottom_right;
       }
     } else {
       if (wpt->longitude < center_lon) {
@@ -894,11 +894,11 @@ wdata_check(writer_data_t* data)
   if (data->top_right) {
     wdata_check(data->top_right);
   }
-  if (data->buttom_left) {
-    wdata_check(data->buttom_left);
+  if (data->bottom_left) {
+    wdata_check(data->bottom_left);
   }
-  if (data->buttom_right) {
-    wdata_check(data->buttom_right);
+  if (data->bottom_right) {
+    wdata_check(data->bottom_right);
   }
 }
 
@@ -1039,11 +1039,11 @@ skip_empty_block:
   if (data->top_right) {
     res += wdata_compute_size(data->top_right);
   }
-  if (data->buttom_left) {
-    res += wdata_compute_size(data->buttom_left);
+  if (data->bottom_left) {
+    res += wdata_compute_size(data->bottom_left);
   }
-  if (data->buttom_right) {
-    res += wdata_compute_size(data->buttom_right);
+  if (data->bottom_right) {
+    res += wdata_compute_size(data->bottom_right);
   }
 
   data->sz = res;
@@ -1191,11 +1191,11 @@ skip_empty_block:
   if (data->top_right) {
     wdata_write(data->top_right);
   }
-  if (data->buttom_left) {
-    wdata_write(data->buttom_left);
+  if (data->bottom_left) {
+    wdata_write(data->bottom_left);
   }
-  if (data->buttom_right) {
-    wdata_write(data->buttom_right);
+  if (data->bottom_right) {
+    wdata_write(data->bottom_right);
   }
 }
 
index a7ff9854b812c947878648018a94015e7cfdf751..5aefddf73e402b9abbb5a5fee16f00590245c4bc 100644 (file)
@@ -298,7 +298,7 @@ icon_mapping_t garmin_icon_table[] = {
   { -1,  8363, "Steak" },
   { -1,  8223, "Street Intersection" },
   { -1, 16401, "TACAN" },
-  { -1,   183, "Tide/Current PRediction Station" },
+  { -1,   183, "Tide/Current Prediction Station" },
   { -1,   191, "U Marina" },
   { -1,  8193, "US hwy" },
   { -1,   193, "U stump" },
index d47797aaa3ba32d66715b002ff114c9ec760bcc6..ca51e75c6724bcd9cf23576efc2e0610a485db79 100644 (file)
@@ -352,7 +352,7 @@ print_position(const Waypoint* wpt)
 
   if (! valid) {
     gbfprintf(fout, "#####\n");
-    fatal(MYNAME ": %s (%s) is outside of convertable area \"%s\"!\n",
+    fatal(MYNAME ": %s (%s) is outside of convertible area \"%s\"!\n",
           wpt->shortname.isEmpty() ? "Waypoint" : qPrintable(wpt->shortname),
           pretty_deg_format(wpt->latitude, wpt->longitude, 'd', nullptr, 0),
           gt_get_mps_grid_longname(grid_index, MYNAME));
@@ -1377,7 +1377,7 @@ garmin_txt_read()
       parse_track_header();
     } else if (case_ignore_strcmp(cin, "Map") == 0) /* do nothing */ ;
     else {
-      fatal(MYNAME ": Unknwon identifier (%s) at line %d!\n", cin, current_line);
+      fatal(MYNAME ": Unknown identifier (%s) at line %d!\n", cin, current_line);
     }
 
     /* flush pending data */
index 4d3ac4caa18d766e699c03ecf81ce18b9cdacce1..2b6a8eede0c7507bbd4601117234057df9570953 100644 (file)
@@ -209,7 +209,7 @@ format_garmin_xt_decomp_trk_blk(uint8_t ii, const uint8_t TrackBlock[], double*
 }
 
 /*
- * Decompose Last Waypoint Eleveation
+ * Decompose Last Waypoint Elevation
  */
 static void
 format_garmin_xt_decomp_last_ele(uint8_t ii, double* PrevEle, const uint8_t TrackBlock[])
index 62256a0b7964aa5ef1c6db8676ba782390dd08d1..47401d9965cbbfa4716bb4cb7f3894e045f52894 100644 (file)
--- a/gbfile.cc
+++ b/gbfile.cc
@@ -301,7 +301,7 @@ stdapi_read(void* buf, const gbsize_t size, const gbsize_t members, gbfile* self
   gbsize_t result = fread(buf, size, members, self->handle.std);
 
   if ((result < members) && (errno = ferror(self->handle.std))) {
-    fatal("%s: Error %d occured during read of file '%s'!\n",
+    fatal("%s: Error %d occurred during read of file '%s'!\n",
           self->module, errno, self->name);
   }
   return result;
@@ -774,7 +774,7 @@ gbfputc(int c, gbfile* file)
  */
 
 // This is a depressing hack, meant to ease the pain from C strings
-// to QStrings, which are consitently encoded.
+// to QStrings, which are consistently encoded.
 int
 gbfputs(const QString& s, gbfile* file)
 {
@@ -1262,4 +1262,4 @@ gbfcopyfrom(gbfile* file, gbfile* src, gbsize_t count)
 }
 
 
-/* Thats all, sorry. */
+/* That's all, sorry. */
diff --git a/gbser.h b/gbser.h
index 5fb8e30bd19bc327d0abfd9c266163bc0d86fbe4..46f4647e50c2dae6d4d00f9a91e934cd036bacc8 100644 (file)
--- a/gbser.h
+++ b/gbser.h
@@ -128,7 +128,7 @@ int gbser_is_serial(const char* port_name);
  * COM ports 1 - 9 are "COM1:" through "COM9:"
  * The one after that is \\.\\com10 - this function tries to plaster over
  * that.
- * It returns a pointer to a staticly allocated buffer and is therefore not
+ * It returns a pointer to a statically allocated buffer and is therefore not
  * thread safe.   The buffer pointed to remains valid only until the next
  * call to this function.
  */
index c241530ac37b0477301c13229b5ab7c8eb2a33f8..9ebaa6a81b9328db9dec055a7876a31bb3a98faa 100644 (file)
@@ -340,7 +340,7 @@ int gbser__fill_buffer(void* handle, unsigned want, unsigned* ms)
         // is incoming data.   This has been shown to trigger driver
         // bugs in the Prolific drivers for Mac and in certain Linux
         // kernels, thought the latter has since been fixed.
-        // So althogh removing this means that the timeout behaviour
+        // So although removing this means that the timeout behaviour
         // is actually different on POSIX and WIN32, it triggers
         // fewer buts this way.  2/12/2008 RJL
         if (/* (rc = set_rx_timeout(h, vmin, vtime), rc < 0) || */
@@ -420,7 +420,7 @@ int gbser_is_serial(const char* port_name)
  * COM ports 1 - 9 are "COM1:" through "COM9:"
  * The one after that is \\.\\com10 - this function tries to plaster over
  * that.
- * It returns a pointer to a staticly allocated buffer and is therefore not
+ * It returns a pointer to a statically allocated buffer and is therefore not
  * thread safe.   The buffer pointed to remains valid only until the next
  * call to this function.
  */
diff --git a/gdb.cc b/gdb.cc
index 5b1f95f0c461ba0fe4dcd31e4906ff498de4c51b..a03fe763dba54cec506f4df8edcfc2641f922e71 100644 (file)
--- a/gdb.cc
+++ b/gdb.cc
@@ -182,8 +182,8 @@ disp_summary(const gbfile* f)
 // all that while (while keeping the character sets correct) and
 // not pushing that decision  down into gbfread.  This module is
 // still pretty messy and the points as to which fields are encode
-// which ways in which versions are not at all clear, leaing to 
-// encoding issues on read and leaks because of teh differences 
+// which ways in which versions are not at all clear, leading to
+// encoding issues on read and leaks because of the differences 
 // in calling conventions on who owns/destroys the result.
 
 #define FREAD_CSTR_AS_QSTR gbfgetcstr(fin)
@@ -435,7 +435,7 @@ read_file_header()
   /*
        A "gbfgetcstr" (FREAD_CSTR) works too, but if we get a wrong file as input,
        the file validation my be comes too late. For example a XML base file normally
-       has no binary zeros inside and produce, if big enought, a buffer overflow.
+       has no binary zeros inside and produce, if big enough, a buffer overflow.
        The following message "local buffer overflow detected..." could be
        misinterpreted.
   */
@@ -856,7 +856,7 @@ read_route()
     }
 
     if (links == 0) {
-      /* Without links we need all informations from wpt */
+      /* Without links we need all information from wpt */
       Waypoint* tmp = gdb_reader_find_waypt(wpt, 0);
       if (tmp != nullptr) {
         delete wpt;
@@ -1277,7 +1277,7 @@ write_waypoint(
 
   int wpt_class = wpt->wpt_flags.fmt_use;              /* trick */
 
-  FWRITE_CSTR(shortname);                      /* uniqe (!!!) shortname */
+  FWRITE_CSTR(shortname);                      /* unique (!!!) shortname */
   FWRITE_i32(wpt_class);                       /* waypoint class */
   FWRITE_CSTR(GMSD_GET(cc, ""));               /* country code */
 
@@ -1342,7 +1342,7 @@ write_waypoint(
       str = "";
     }
     FWRITE_CSTR(str);
-    FWRITE(zbuf, 5);                           /* instruction dependend */
+    FWRITE(zbuf, 5);                           /* instruction dependent */
 
     /* GBD doesn't have a native description field */
     /* here we misuse the instruction field */
index b6f5a786f40f4077e21084b02496fd2aed447781..0a0063e5a44c00ae3c4437c08257993b2b0ae676 100644 (file)
@@ -22,7 +22,7 @@
 /*
  * This is the bridge between the GPSBabel and globalsat sport devices
  * gh625XT. Globalsat has a few devices under the sport brand and they
- * are using a similar USB serial protocal.
+ * are using a similar USB serial protocol.
  * Currently only gh625XT is supported by this driver but the code could
  * extended (maybe autodetect) support more devices in the future.
  *
@@ -52,8 +52,8 @@ static char* track = nullptr;                     // if not 0 only download this
 
 static char* opt_dump_file = nullptr;              // dump raw data to this file (optional)
 static char* opt_input_dump_file = nullptr;    // if true input is from a dump-file instead of serial console
-static gbfile* dumpfile = nullptr;             // used for creating bin/RAW datadump files, usefull for testing
-static gbfile* in_file = nullptr;              // used for reading from bin/RAW datadump files, usefull for testing
+static gbfile* dumpfile = nullptr;             // used for creating bin/RAW datadump files, useful for testing
+static gbfile* in_file = nullptr;              // used for reading from bin/RAW datadump files, useful for testing
 
 static
 arglist_t globalsat_args[] = {
@@ -91,7 +91,7 @@ typedef enum {
   HeaderTypeLaps = 0xAA,
   HeaderTypeTrackPoints = 0x55,
 
-  ResponseInsuficientMemory = 0x95,
+  ResponseInsufficientMemory = 0x95,
   ResponseResendTrackSection = 0x92,
   ResponseSendTrackFinish = 0x9A
 } globalsat_commands_e;
@@ -260,7 +260,7 @@ recv_byte()
     int bytes = gbfread(&result, 1, 1, in_file);
     is_fatal((bytes != 1), MYNAME ": read error");
   }
-  // Check if byte sould be dumped also into a file
+  // Check if byte should be dumped also into a file
   if (dumpfile) {
     gbfwrite(&result, 1, 1, dumpfile);
   }
@@ -377,7 +377,7 @@ static void
 globalsat_probe_device()
 {
   //TODO try this first if fails try with false, to support 561
-  isSizeSwapped = false;               //all devices but gh561 since gh561 has swaped size.
+  isSizeSwapped = false;               //all devices but gh561 since gh561 has swapped size.
 
   globalsat_send_simple(CommandWhoAmI);
 
@@ -408,7 +408,7 @@ rd_init(const QString& fname)
       printf(MYNAME " rd_init() creating dumpfile %s FAILED continue anyway\n",opt_dump_file);
     } else {
       if (global_opts.debug_level > 1) {
-        printf(MYNAME " rd_init() creating dumpfile %s for writing binnary copy of serial stream\n",opt_dump_file);
+        printf(MYNAME " rd_init() creating dumpfile %s for writing binary copy of serial stream\n",opt_dump_file);
       }
     }
   }
@@ -568,7 +568,7 @@ track_read()
         uint8_t trackDeviceCommand;
         int track_length;
         uint8_t* track_payload = globalsat_read_package(&track_length, &trackDeviceCommand);
-        is_fatal(((track_length == 0) || (track_payload == nullptr)) , "tracklength in 0 bytes or payload nonexistant");
+        is_fatal(((track_length == 0) || (track_payload == nullptr)) , "track length is 0 bytes or payload nonexistent");
         //      printf("Got track package!!! Train data\n");
 
         uint8_t* dbtrain = track_payload;
@@ -623,7 +623,7 @@ track_read()
         while (total_laps_left > 0) {
           globalsat_send_simple(CommandGetNextTrackSection);
           track_payload = globalsat_read_package(&track_length, &trackDeviceCommand);
-          is_fatal(((track_length == 0) || (track_payload == nullptr)), "tracklength in 0 bytes or payload nonexistant");
+          is_fatal(((track_length == 0) || (track_payload == nullptr)), "track length is 0 bytes or payload nonexistent");
           //   printf("Got track package!!! Laps data\n");
 
           uint8_t* hdr = track_payload;
@@ -755,8 +755,8 @@ track_read()
               point.PwrCadence = be_readu16(ghpoint+21);
               point.Power = be_readu16(ghpoint+23);
 
-              //Time from last point in sec's * 10 (e.g. point.lntervalTime is sec multiplied witn 10)
-              // convert to milisecs
+              //Time from last point in sec's * 10 (e.g. point.IntervalTime is sec multiplied with 10)
+              // convert to millisecs
               gpsbabel::DateTime gpsbabeltime = gpsDateTime.addMSecs(point.IntervalTime*100);
               gpsbabeltime.setTimeSpec(Qt::UTC);
               gpsDateTime.setDate(gpsbabeltime.date());
@@ -828,7 +828,7 @@ data_read()
   }
 }
 
-// This used the serial comunication to the watch
+// This used the serial communication to the watch
 ff_vecs_t globalsat_sport_vecs = {
   ff_type_serial,              //type
   FF_CAP_RW_ALL,               //cap[3]
@@ -847,7 +847,7 @@ ff_vecs_t globalsat_sport_vecs = {
 };
 
 // This reads from a RAW dump bile from a watch
-// Usefull for testing generata a dumpfile with
+// Useful for testing generated dumpfile with
 // gpsbabel -i globalsat,dump-file=<dumpfilename> -f /dev/ttyUSB0 -o gpx,garminextensions -F <1:st gpx file name>
 // gpsbabel -i globalsat-bin -f <dumpfilename> -o gpx,garminextensions -F <2:nd gpx file name>
 ff_vecs_t globalsat_sport_fvecs = {
index 0ec292a5655e35ab51ead865bc926e299ba08a03..1734a492583917ab630b06b47a43d795c207f7a2 100644 (file)
--- a/gopal.cc
+++ b/gopal.cc
@@ -29,7 +29,7 @@
        in the data, i.e. only one data point shows a totally wrong longitude or latitude. Everything else in
        the dataset seems ok, so I needed a way to sort out these errors. My solution is to calculate the speed
        between successive points and drop points not between minspeed and maxspeed. This way I can sort out most
-       of this annoying bugs, a side effect is that if a minimum speed > 0 is set points with the same coodinates are also
+       of this annoying bugs, a side effect is that if a minimum speed > 0 is set points with the same coordinates are also
        dropped.
 
        Fileformat GoPal
@@ -147,7 +147,7 @@ gopal_rd_init(const QString& fname)
     } else if (filename.startsWith("A_")&&(filename.length()>10)) { // here we expect at least 10 letters: A_YYYYMMDD...
       datestr = filename.mid(2,8);
     }
-    // in buff we should now have something wich looks like a valid date starting with YYYYMMDD
+    // in buff we should now have something which looks like a valid date starting with YYYYMMDD
     /*ck = (char*)*/strptime(qPrintable(datestr), "%Y%m%d", &filenamedate);
     // if (((ck == NULL) || (*ck != '\0') )&&!(optdate))
     // fatal(MYNAME ": Invalid date in filename \"%s\", try to set manually using \"date\" switch!\n", buff);
index 4bdfdc49c513b2614c3bf95ccf05a3f9bac34a5f..ad3457b7c4f02ba77c51982ac654fcdc3a1a53ec 100644 (file)
@@ -102,7 +102,7 @@ data_read()
     int n = sscanf(ibuf, "%lf%c %lf%c %ld%c %30[^,] %2s",
                    &lat, &latdir, &lon, &londir,
                    &alt, &alttype, desc, icon);
-    /* Require at least first threee fields, otherwise ignore */
+    /* Require at least first three fields, otherwise ignore */
     if (n < 2) {
       xfree(sn);
       continue;
diff --git a/gpx.cc b/gpx.cc
index 5f126a840fdd4ab4b2d2b48707e9852740786ebc..0a30c97859009cc0fb7daf2a95c188d0da88c343 100644 (file)
--- a/gpx.cc
+++ b/gpx.cc
@@ -282,7 +282,7 @@ gpx_write_gdata(const QStringList& ge, const QString& tag)
     writer->writeStartElement(tag);
     // TODO: This seems questionable.
     // We concatenate element content from multiple elements,
-    // possibly from muliple input files, into one element.
+    // possibly from multiple input files, into one element.
     // This is necessary to comply with the schema as
     // these elements have maxOccurs limits of 1.
     for (const auto& str : ge) {
@@ -305,9 +305,9 @@ typedef struct tag_mapping {
 } tag_mapping;
 
 /*
- * xpath(ish) mappings between full tag paths and internal identifers.
+ * xpath(ish) mappings between full tag paths and internal identifiers.
  * These appear in the order they appear in the GPX specification.
- * If it's not a tag we explictly handle, it doesn't go here.
+ * If it's not a tag we explicitly handle, it doesn't go here.
  */
 
 /* /gpx/<name> for GPX 1.0, /gpx/metadata/<name> for GPX 1.1 */
@@ -635,7 +635,7 @@ tag_log_wpt(const QXmlStreamAttributes& attr)
   }
   /* Make a new shortname.  Since this is a groundspeak extension,
     we assume that GCBLAH is the current shortname format and that
-    wpt_tmp refers to the currently parsed waypoint. Unfortunatley,
+    wpt_tmp refers to the currently parsed waypoint. Unfortunately,
     we need to keep track of log_wpt counts so we don't collide with
     dupe shortnames.
   */
@@ -753,7 +753,7 @@ struct
   { gt_event, "Event" }, /* opencaching.de */
   { gt_webcam, "Webcam Cache" },
   { gt_webcam, "Webcam" }, /* opencaching.de */
-  { gt_suprise, "Unknown Cache" },
+  { gt_surprise, "Unknown Cache" },
   { gt_earth, "Earthcache" },
   { gt_earth, "Earth" }, /* opencaching.de */
   { gt_cito, "Cache In Trash Out Event" },
diff --git a/gtm.cc b/gtm.cc
index 616a060548e07d68266ea3c788109d47b0ad6a80..359de8303597bc2dba2ac3a41388945c63fd6c55 100644 (file)
--- a/gtm.cc
+++ b/gtm.cc
@@ -179,7 +179,7 @@ fwrite_fixedstring(gbfile* fd, const QString& str, int fieldlen)
   fwrite_fixedstring(fd, CSTR(str), fieldlen);
 }
 
-/* Auxiliar functions */
+/* Auxiliary functions */
 
 #define MAX_INDATUM_INDEX 263
 
index 6661a813eed66f71a844c9c0e43ad7f735161493..06fe25d20a8ab429efb1f8544b601f74aa32a5e0 100644 (file)
@@ -820,7 +820,7 @@ humminbird_track_cb(const Waypoint* wpt)
     be_write16(&trk_points[j].deltanorth, trk_points[j].deltanorth);
     be_write16(&trk_points[j].depth, trk_points[j].depth);
 
-    /* Update bounding box in header if neccessary */
+    /* Update bounding box in header if necessary */
     if (east > trk_head->ne_east) {
       trk_head->ne_east = east;
     }
diff --git a/kml.cc b/kml.cc
index a63750d84e28d76ea4a2e7c6bd9cb69967204eba..6f8fe2ffaf01ce780088bed10bcb79a5f3cd8f04 100644 (file)
--- a/kml.cc
+++ b/kml.cc
@@ -887,7 +887,7 @@ int kml_altitude_known(const Waypoint* waypoint)
   if (waypoint->altitude == unknown_alt) {
     return 0;
   }
-  // We see way more data that's sourceed at 'zero' than is actually
+  // We see way more data that's sourced at 'zero' than is actually
   // precisely at 0 MSL.
   if (fabs(waypoint->altitude) < 0.01) {
     return 0;
@@ -941,7 +941,7 @@ static void kml_output_positioning(bool tessellate)
 
 }
 
-/* Output something interesing when we can for route and trackpoints */
+/* Output something interesting when we can for route and trackpoints */
 static void kml_output_description(const Waypoint* pt)
 {
   const char* alt_units;
@@ -1257,7 +1257,7 @@ void kml_gc_make_balloonstyletext()
 
   cdataStr.append("  <ul>\n");
   // Fortunately, all the mappy map URLs take lat/longs in the URLs, so
-  // the substition is easy.
+  // the substitution is easy.
   for (int tp = 0; !map_templates[tp].isEmpty(); tp++) {
     cdataStr.append("    <li>\n");
     cdataStr.append("    ");
@@ -1355,7 +1355,7 @@ kml_lookup_gc_icon(const Waypoint* waypointp)
   case gt_locationless:
     icon = "8.png";
     break; // No unique icon.
-  case gt_suprise:
+  case gt_surprise:
     icon = "8.png";
     break;
   case gt_webcam:
diff --git a/lmx.cc b/lmx.cc
index 5df635ed927313fffd0ecdbca36f9265a33c58bf..b91552bd672d824718a008ce73d71a6b5e16d43d 100644 (file)
--- a/lmx.cc
+++ b/lmx.cc
@@ -199,7 +199,7 @@ static void
 lmx_print(const Waypoint* wpt)
 {
   /*
-   * Desparation time, try very hard to get a good shortname
+   * Desperation time, try very hard to get a good shortname
    */
   QString odesc = wpt->notes;
   if (odesc.isEmpty()) {
index c3833d4c71e376e90376e1c61b27e04cf2abff9b..46b3fd7afecaf62c9625d5da818c7e872faffc91 100644 (file)
@@ -37,8 +37,8 @@
       format data.
     - Combined processing of USR 2/3/4/5/6 formats into a single
       file. The previous implementation did not support conversion
-      between USR 2/3 and 4/5/6 or between 4/5/6 and 2/3 beause of
-      the seperation in processing between lowranceusr.cc and
+      between USR 2/3 and 4/5/6 or between 4/5/6 and 2/3 because of
+      the separation in processing between lowranceusr.cc and
       lowranceusr4.cc.
 
   USR Background Information
@@ -60,7 +60,7 @@
 
       User Data File version 4 - USRv4
         Seems to be the best option for transferring data from older Lowrance units.
-        Many of the counts (Number of Waypoints, Number of Routes, etc) were exanded from
+        Many of the counts (Number of Waypoints, Number of Routes, etc) were expanded from
         16-bit integer values (maximum value of 65,535) to 32-bit (maxumum value 2,147,483,647)
         USRv4 and above support a maximum of 20,000 trail-points (actually 24K and change).
         USRv4 and above and GPX support trails with trail-segments.
index 69159f8af4d7dcd4130c00c2729fd90cc5421bd9..61cf77b2273dc36f644af7ace15f16cf2a1ec4a4 100644 (file)
--- a/maggeo.cc
+++ b/maggeo.cc
@@ -147,7 +147,7 @@ maggeo_read()
         break;
       case 12: // cache type
         if (strcmp(s, "Mystery Cache") == 0) {
-          gcdata->type = gt_suprise;
+          gcdata->type = gt_surprise;
         } else {
           gcdata->type = gs_mktype(s);
         }
@@ -256,7 +256,7 @@ maggeo_waypt_pr(const Waypoint* waypointp)
    * For some reason, Magellan used exactly the GPX spellings of
    * everything except this one...
    */
-  if (waypointp->gc_data->type == gt_suprise) {
+  if (waypointp->gc_data->type == gt_surprise) {
     ctype = "Mystery Cache";
   } else {
     ctype = gs_get_cachetype(waypointp->gc_data->type);
index ab3ed6e91562b1d7827d4ee90f4db04e861192c7..a8f139364a09eb41cf41ef00b0d409e12899ab29 100644 (file)
@@ -74,7 +74,7 @@ static int waypoint_read_count;
 static int wpt_len = 8;
 static QString curfname;
 static int extension_hint;
-// For Explorist GC/510/610/710 familes, bludgeon in GPX support.
+// For Explorist GC/510/610/710 families, bludgeon in GPX support.
 // (This has nothing to do with the Explorist 100...600 products.)
 static ff_vecs_t* gpx_vec;
 static mag_info* explorist_info;
@@ -85,8 +85,8 @@ static QStringList os_gpx_files(const char* dirname);
  * we turn around an ack while we are reading from the device.  It's
  * quite spiffy when we're writing to the device.   Since we're *way*
  * less likely to lose data while reading from it than it is to lose data
- * when we write to it, we turn off the acks when we are predominatly
- *  reading.
+ * when we write to it, we turn off the acks when we are predominantly
+ * reading.
  */
 static int suppress_ack;
 
@@ -201,7 +201,7 @@ static icon_mapping_t map330_icon_table[] = {
   { "ah", "Virtual cache"},    /* Binos: because you "see" them. */
   { "ak", "Micro-Cache" },     /* Looks like a film canister. */
   { "an", "Multi-Cache"},      /* Winery: grapes 'coz they "bunch" */
-  { "s",  "Unknown Cache"},    /* 'Suprise' cache: use a target. */
+  { "s",  "Unknown Cache"},    /* 'Surprise' cache: use a target. */
   { "ac",  "Event Cache"},     /* Event caches.  May be food. */
   { nullptr, nullptr }
 };
diff --git a/main.cc b/main.cc
index 5efea6b27a1ba156af4ed1c7195fe7b8e5e1826e..6c7c6a2fe0204f3ef0e9cd4a8a4f34e26095d41c 100644 (file)
--- a/main.cc
+++ b/main.cc
@@ -720,7 +720,7 @@ main(int argc, char* argv[])
   global_opts.inifile = nullptr;
 
   gpsbabel_now = time(nullptr);                        /* gpsbabel startup-time */
-  gpsbabel_time = current_time().toTime_t();                   /* same like gpsbabel_now, but freezed to zero during testo */
+  gpsbabel_time = current_time().toTime_t();                   /* same like gpsbabel_now, but frozen at zero during testo */
 
   if (gpsbabel_time != 0) {    /* within testo ? */
     global_opts.inifile = inifile_init(QString(), MYNAME);
index 2a80e44980ccc93426f6d137dc348bf8238ee2b4..72c26eb673db7b89009aa09e6d4f1162bfd2585a 100644 (file)
@@ -328,7 +328,7 @@ mps_readstr(gbfile* mps_file, char* buf, size_t sz)
 }
 
 /*
- * read in from file to check a) valid format b) version of data formating
+ * read in from file to check a) valid format b) version of data formatting
  * MRCB
  */
 static void
@@ -355,7 +355,7 @@ mps_fileHeader_r(gbfile* mps_file, int* mps_ver)
   } else if ((hdr[1] > 'h') && (hdr[1] <= 'i')) {
     *mps_ver = 5;
   } else {
-    fatal(MYNAME ": Unsuppported version of mapsource file.\n");
+    fatal(MYNAME ": Unsupported version of mapsource file.\n");
   }
   /* Skip reliably over the "format details" section */
   gbfseek(mps_file, reclen+1-3, SEEK_CUR);
index 927a6874e21e5869a7ebe6c1138f88a419d54768..25e936fec74d36e136fca2d630fe4d3147c140be 100644 (file)
@@ -203,7 +203,7 @@ char*
 delete_last_vowel(int start, char* istring, int* replaced)
 {
   /*
-   * Basically impelement strrchr.
+   * Basically implement strrchr.
    */
   *replaced = 0;
   for (int l = strlen(istring); l > start; l--) {
@@ -236,7 +236,7 @@ replace_constants(char* s)
   for (struct replacements* r = replacements; r->orig; r++) {
     int rl = strlen(r->orig);
     /*
-     * If word is in replacement list and preceeded by a
+     * If word is in replacement list and preceded by a
      * space, replace it.
      */
     if ((origslen - rl > 1) &&
index 69138be864eb2290119febd33e3ff15d126512a8..7ce3b28fc7f5ea3fb719f408e3e50f0bdcdf2979 100755 (executable)
@@ -1,7 +1,7 @@
 #!/bin/sh
 
 echo "/* This file is machine-generated from the contents of style/ */"
-echo "/* by mkstyle.sh.   Editing it by hand is an exeedingly bad idea. */"
+echo "/* by mkstyle.sh.   Editing it by hand is an exceedingly bad idea. */"
 echo 
 
 # set the locale for sorting so that the collate order doesn't depend
diff --git a/mmo.cc b/mmo.cc
index 3f7b219f6b9f21401913d25d4bd424b99c372404..747018445fe16f2ff9a989291bb2dcc8a55c5127 100644 (file)
--- a/mmo.cc
+++ b/mmo.cc
@@ -75,7 +75,7 @@ typedef struct mmo_data_s {
   gpsdata_type type;   /* type of "data" */
   time_t ctime;
   time_t mtime;
-  int left;            /* number of un-readed route points */
+  int left;            /* number of unread route points */
   void* data;          /* can be a waypoint, a route or a track */
   int refct;
   struct mmo_data_s** members;
@@ -132,9 +132,9 @@ static const mmo_icon_mapping_t mmo_icon_value_table[] = {
   { 0x11, "Triangle" },
   { 0x12, "Square" },
   { 0x13, "Circle" },
-  { 0x14, "Green bouy" },
-  { 0x15, "Red bouy" },
-  { 0x16, "Yellow bouy" },
+  { 0x14, "Green buoy" },
+  { 0x15, "Red buoy" },
+  { 0x16, "Yellow buoy" },
   { 0x17, "Geocache" },
 
   { -1, nullptr }
@@ -1109,7 +1109,7 @@ mmo_writestr(const char* str)
 static void
 mmo_writestr(const QString& str)
 {
-  // If UTF-8 is used instgead of Latin1, we fail in weird ways.
+  // If UTF-8 is used instead of Latin1, we fail in weird ways.
   mmo_writestr(str.toLatin1().constData());
 }
 
index e981215dc07467110fab6d333785f03d731cb7ec..b7687240af74ccf47e51512c38a1273e017f0c03 100644 (file)
@@ -893,7 +893,7 @@ static int add_trackpoint(int idx, unsigned long bmask, struct data_item* itm)
   }
 
   // RCR is a bitmask of possibly several log reasons..
-  // Holux devics use a Event prefix for each waypt.
+  // Holux devices use a Event prefix for each waypt.
   if (global_opts.masked_objective & WPTDATAMASK
       && ((bmask & (1U<<RCR) && itm->rcr & 0x0008)
           || (mtk_info.track_event & MTK_EVT_WAYPT)
index f1dea600bad27b9722d105ef846a2a74140a90d8..b2983fb7aa1da91de183bbea5419f29e4b85214f 100644 (file)
@@ -123,7 +123,7 @@ data_read()
 
       /*
        * Mac stumbler files are the same, except
-       * use DDMM.mmm instad of DD.DDDD.
+       * use DDMM.mmm instead of DD.DDDD.
        */
       if (strstr(ibuf, "Creator: MacStumbler")) {
         macstumbler = 1;
diff --git a/nmea.cc b/nmea.cc
index 9f6faded7073267ad01964fb6f2daefd1cdc7b3e..403040ab13a7c4d53b0fb668c0b9f0364592a191 100644 (file)
--- a/nmea.cc
+++ b/nmea.cc
@@ -706,7 +706,7 @@ gpzda_parse(char* ibuf)
 // bunch of nested sscanfs. In 2017, robertl replaced the scanf stuff with
 // a QString::split() to make it more tolerant of really empty fields from
 // certain GPS implementations, but didn't replace the (somewhat funky) back
-// half to match the parse. There are definitely some readibility issues
+// half to match the parse. There are definitely some readability issues
 // here.
 // The numbering as per http://aprs.gids.nl/nmea/#gsa was the reference as
 // the field numbers conveniently match our index.
@@ -883,7 +883,7 @@ nmea_fix_timestamps(route_head* track)
 
     if (optdate == nullptr) {
       warning(MYNAME ": No date found within track (all points dropped)!\n");
-      warning(MYNAME ": Please use option \"date\" to preset a valid date for thoose tracks.\n");
+      warning(MYNAME ": Please use option \"date\" to preset a valid date for those tracks.\n");
       track_del_head(track);
       return;
     }
@@ -930,11 +930,11 @@ notalkerid_strmatch(const char * s1, const char *sentenceFormatterMnemonicCode)
 {
 /*
  * compare leading start of parametric sentence character ('$'), sentence address field, and trailing comma
- * to the desired sentence formatter mneumonic code (the 3rd-5th characters of the sentence address field).
- * The talker identifier mneumonic (the 1st-2nd characters of the sentence address field)
- * is likely "GP" for Global Posilioning System (GPS)
+ * to the desired sentence formatter mnemonic code (the 3rd-5th characters of the sentence address field).
+ * The talker identifier mnemonic(the 1st-2nd characters of the sentence address field)
+ * is likely "GP" for Global Positioning System (GPS)
  * but other talkers like "IN" for Integrated Navigation can emit relevant sentences,
- * so we ignore the talker identifier mneumonic.
+ * so we ignore the talker identifier mnemonic.
  */
 return strncmp(s1,"$",1) || strncmp(s1+3,sentenceFormatterMnemonicCode,3) || strncmp(s1+6,",",1);
 }
@@ -1022,7 +1022,7 @@ nmea_parse_one_line(char* ibuf)
   }
 
   if (tbuf != ibuf) {
-    /* clear up the dynamic buffer we used because substition was required */
+    /* clear up the dynamic buffer we used because substitution was required */
     xfree(tbuf);
   }
 }
diff --git a/nmn4.cc b/nmn4.cc
index 906050247efbc75fe74fdb4ff66ab73236c920cc..c2b0c2c9e69f268c036849c04e28091cf915a915 100644 (file)
--- a/nmn4.cc
+++ b/nmn4.cc
@@ -153,7 +153,7 @@ nmn4_read_data()
           }
         }
 
-        /* concats all fields to one string and release */
+        /* concatenates all fields to one string and release */
         wpt->description = zip1.trimmed() + " " +
           city.trimmed() + " " +
           street.trimmed() + " " +
index b1cf195323906f6b189d88eff740ebc179e824a2..62b099d6d334b5e354f7923cc68a767f78531201 100644 (file)
--- a/parse.cc
+++ b/parse.cc
@@ -45,7 +45,7 @@ parse_distance(const char* str, double* val, double scale, const char* module)
   }
   *val = strtod(str, &unit);
   if (unit == nullptr) {
-    fatal("%s: Unconvertable numeric value (%s)!\n", module, str);
+    fatal("%s: Unconvertible numeric value (%s)!\n", module, str);
   }
 
   if (fabs(*val) + 1 >= 1.0e25) {
@@ -106,7 +106,7 @@ parse_speed(const char* str, double* val, const double scale, const char* module
 
   *val = strtod(str, &unit);
   if (unit == nullptr) {
-    fatal("%s: Unconvertable numeric value (%s)!\n", module, str);
+    fatal("%s: Unconvertible numeric value (%s)!\n", module, str);
   }
 
   while (isspace(*unit)) {
@@ -150,10 +150,10 @@ parse_speed(const QString& str, double* val, const double scale, const char* mod
 }
 
 /*
- * Convert string 'str' into geodetic latitide & longitude values. The format
+ * Convert string 'str' into geodetic latitude & longitude values. The format
  * will be interpreted depending on 'grid' parameter.
  *
- * return value: number of characters efective parsed
+ * return value: number of characters parsed
  */
 
 int
diff --git a/pcx.cc b/pcx.cc
index e3e4aa77792998191a10333dbb16e04d2d555d19..a6dd3b064ccce4126c7e91937dba6890a858befe 100644 (file)
--- a/pcx.cc
+++ b/pcx.cc
@@ -189,9 +189,9 @@ static void data_read() {
       }
       case 'H':
         /* Garmap2 has headers
-        "H(2 spaces)LATITUDE(some spaces)LONGTITUDE(etc... followed by);track
+        "H(2 spaces)LATITUDE(some spaces)LONGITUDE(etc... followed by);track
           everything else is
-          H(2 chars)TN(tracknane\0)
+          H(2 chars)TN(trackname\0)
           */
         if (points > 0) {
           track = nullptr;
@@ -326,7 +326,7 @@ static void pcx_track_hdr(const route_head* trk) {
       mkshort(mkshort_handle2,
               trk->rte_name.isEmpty() ? CSTR(default_name) : trk->rte_name);
   /* Carto Exploreur (popular in France) chokes on trackname headers,
-   * so provide option to supppress these.
+   * so provide option to suppress these.
    */
   if (!cartoexploreur) {
     gbfprintf(file_out, "\n\nH  TN %s\n", CSTR(name));
index 2fae2b95f1da91f68ef6c9aa0045d8bf060c8820..e7eb69348f28fb3eb29725f2c88093c5a72f8f66 100644 (file)
@@ -62,7 +62,7 @@ private:
       nullptr, ARGTYPE_BOOL, ARG_NOMINMAX, nullptr
     },
     {
-      "time", &timeopt, "Maximum time in seconds beetween two points",
+      "time", &timeopt, "Maximum time in seconds between two points",
       nullptr, ARGTYPE_FLOAT | ARGTYPE_REQUIRED, ARG_NOMINMAX, nullptr
     },
     ARG_TERMINATOR
index 630eef703d45d1b52e22d37ac0c8c2f02d5301ee..8b37e743ac3e66fad30717c7537faefe40872553 100644 (file)
@@ -5,7 +5,7 @@
 # Waypoint name
 # Waypoint comment
 # Waypoint description
-# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)
+# Latitude in Degree and decimals (southern hemisphere has neg. degrees)
 # Longitude in degree and decimals (neg. numbers: west of Greenwich)
 # Height in meters
 GCEBB,Mountain Bike Heaven by susy1313,,35.9720333,-87.1347000,0.0
index 7e07be7681393e7ddbac7c196cf12e3e93ca8c35..677b10e2fe17445fa516b0ba16d4e3c14845ae9e 100644 (file)
@@ -5,7 +5,7 @@
 # Waypoint name
 # Waypoint comment
 # Waypoint description
-# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)
+# Latitude in Degree and decimals (southern hemisphere has neg. degrees)
 # Longitude in degree and decimals (neg. numbers: west of Greenwich)
 # Height in meters [optional when importing, always present when exporting: Date (GMT) as ISO YYYYMMDD, Time of the day relative to the date as HHMMSS
 GCEBB,Mountain Bike Heaven by susy1313,,35.9720333,-87.1347000,0.0    ,19700101,000000
index 4ad0e3b1c98b8d97e04c41bb4da8697444bff745..beec07180b9d011b53870f688406c4203a9dc74f 100644 (file)
@@ -5,7 +5,7 @@
 # Waypoint name
 # Waypoint comment
 # Waypoint description
-# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)
+# Latitude in Degree and decimals (southern hemisphere has neg. degrees)
 # Longitude in degree and decimals (neg. numbers: west of Greenwich)
 # Height in meters [optional when importing, always present when exporting: Date (GMT) as ISO YYYYMMDD, Time of the day relative to the date as HHMMSS
 GCEBB,Mountain Bike Heaven by susy1313,,35.9720333,-87.1347000,0.0    ,19700101,000000
index 8981db7fec141c252bd3fee8798f3fb13790d9a9..b7b2538efcdcf5804d2f08774c979d389500c90a 100644 (file)
@@ -5,7 +5,7 @@
 # Waypoint name
 # Waypoint comment
 # Waypoint description
-# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)
+# Latitude in Degree and decimals (southern hemisphere has neg. degrees)
 # Longitude in degree and decimals (neg. numbers: west of Greenwich)
 # Height in meters [optional when importing, always present when exporting: Date (GMT) as ISO YYYYMMDD, Time of the day relative to the date as HHMMSS
 GCEBB,Mountain Bike Heaven by susy1313,,35.9720333,-87.1347000,0.0
index ba823789105f091de21af4cc159b49a1e1b9879e..3ebd881fb6cfa74e5574c99b3e33909e880d21b2 100644 (file)
@@ -5,7 +5,7 @@
 # Waypoint name
 # Waypoint comment
 # Waypoint description
-# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)
+# Latitude in Degree and decimals (southern hemisphere has neg. degrees)
 # Longitude in degree and decimals (neg. numbers: west of Greenwich)
 # Height in meters [optional when importing, always present when exporting: Date (GMT) as ISO YYYYMMDD, Time of the day relative to the date as HHMMSS
 ,,,30.0621833,-91.6103500,1.0    ,20020525,170621
index 1cd3746dc6c676ed4bab6653bd20799292a2e497..6f0c76128d27227780b45bc967d13a6c3edbfb47 100644 (file)
--- a/shape.cc
+++ b/shape.cc
@@ -245,7 +245,7 @@ my_read()
         bool ok;
         int fieldIdx = opt_name_fields.at(oidx).toInt(&ok);
         if (ok) {
-          // retrieve name commponent from given field number
+          // retrieve name component from given field number
           check_field_index(fieldIdx);
         } else {
           // retrieve name component from given field name.
index 654d49d5ca7d949e1fe0086cfdfd6753de271cfc..6fa92d80d1e0e5ea8469832c968ab23045197ee7 100644 (file)
@@ -1521,7 +1521,7 @@ static int getPoiByName(char* name)
 }
 #endif
 // Convert lla (lat, lng, alt) to ECEF
-// Algorith taken from these sources:
+// Algorithm taken from these sources:
 // http://www.mathworks.com/matlabcentral/fileexchange/7942-covert-lat-lon-alt-to-ecef-cartesian
 // http://en.wikipedia.org/wiki/Geodetic_system#From_ECEF_to_geodetic
 // http://earth-info.nga.mil/GandG/publications/tr8350.2/wgs84fin.pdf
@@ -1667,7 +1667,7 @@ miniHomer_read()
     npoi++;
   }
   if (npoi == 0) {                             // do not read if POIs are set (consider set & read distinct operations)
-    skytraq_read();                            // first read tracks (if not supressed by cmd line params)
+    skytraq_read();                            // first read tracks (if not suppressed by cmd line params)
     // we need this call it initialized waypoint list etc...
     skytraq_rd_deinit();               // skytraq_read called system_reset, which changes the baud rate.
 
index e24ff9a1b2bd09ac767b49e7fd7f6732eacf41a9..5b66e4d26456add6dc246a445928aa120f60e73d 100644 (file)
@@ -82,7 +82,7 @@ XmlStreamWriter::XmlStreamWriter(QFile* f) : QXmlStreamWriter(f)
   setCodec(XmlTextCodec::instance);
 }
 
-// We must overide the encoding, we don't want to use XmlTextCode::name().
+// We must override the encoding, we don't want to use XmlTextCode::name().
 void XmlStreamWriter::writeStartDocument()
 {
   writeProcessingInstruction(QStringLiteral("xml version=\"1.0\" encoding=\"UTF-8\""));
index aa1d5b2db25fa33e85bc645511eb741f51007b6d..c6e65925d66cd7bb3047b42b57641ec85c2c6141 100644 (file)
@@ -24,7 +24,7 @@ PROLOGUE \#
 PROLOGUE \# Waypoint name
 PROLOGUE \# Waypoint comment
 PROLOGUE \# Waypoint description
-PROLOGUE \# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)
+PROLOGUE \# Latitude in Degree and decimals (southern hemisphere has neg. degrees)
 PROLOGUE \# Longitude in degree and decimals (neg. numbers: west of Greenwich)
 PROLOGUE \# Height in meters [optional when importing, always present when exporting: Date (GMT) as ISO YYYYMMDD, Time of the day relative to the date as HHMMSS
 
index d3444fe08760ee7c02903cea97202b5c959046f6..4f0d03b7e5d36b29a53728f0a7cb8a9b8a749710 100644 (file)
@@ -11,7 +11,7 @@ SHORTWHITE            0
 
 #
 #
-# FILE LAYOUT DEFINITIIONS:
+# FILE LAYOUT DEFINITIONS:
 #
 FIELD_DELIMITER                COLON
 RECORD_DELIMITER       NEWLINE
diff --git a/tpo.cc b/tpo.cc
index 55ab0c06d86b4eb2eca6c79278347e0bec4257df..a90af11a4cf550946a118c3d7dca8cfdc6c8c6ac 100644 (file)
--- a/tpo.cc
+++ b/tpo.cc
@@ -105,7 +105,7 @@ arglist_t tpo2_args[] = {
 };
 */
 //
-// Note that we've disabled the write capabilites for the tpo2
+// Note that we've disabled the write capabilities for the tpo2
 // format at present.  The "testo" tests were failing on some
 // platforms and there wasn't anyone willing to work on the problem.
 // If this is fixed in the future we can go back to the tpo2_args[]
@@ -359,7 +359,7 @@ static void tpo_read_2_x()
         78);
 
       /* there is no elevation data for the waypoints */
-      /* this is unecessary, the constructor will do this anyway. */
+      /* this is unnecessary, the constructor will do this anyway. */
       waypoint_temp->altitude = unknown_alt;
 
       track_add_wpt(track_temp, waypoint_temp);
@@ -850,7 +850,7 @@ static void tpo_process_waypoints()
     // The original untested check for unknown altitude was for 0xfffd000c (-196596 cm),
     // but a test case submitted later used 0xffce0000 (-3276800 cm).
     if (altitude == -3276800) { // Unknown altitude
-      /* this is unecessary, the constructor will do this anyway. */
+      /* this is unnecessary, the constructor will do this anyway. */
       waypoint_temp->altitude = unknown_alt;
     } else {
       waypoint_temp->altitude = (double) altitude / 100.0;   // Meters
@@ -1275,7 +1275,7 @@ static void
 tpo_rd_init(const QString& fname)
 {
 
-  // preprare for an attempt to deallocate memory that may or may not get allocated
+  // prepare for an attempt to deallocate memory that may or may not get allocated
   // depending on the options used.
   tpo_index_ptr = 0;
   tpo_wp_index = nullptr;
@@ -1368,7 +1368,7 @@ tpo_read()
    3. Add a new if() clause to tpo_write_file_header(). Copy the header bytes definition
    from the previous step.
    4. Recompile gpsbabel.
-   5. You should now be able write TPO ouput in the new state's format. For example, if
+   5. You should now be able write TPO output in the new state's format. For example, if
       you added support for Texas:
      gpsbabel -t -i gpx -f input.gpx -o tpo,state="TX" -F output.tpo */
 static void
@@ -1610,7 +1610,7 @@ tpo_write_file_header()
   }
 
   else {
-    fatal(MYNAME ": writing ouput for state \"%s\" is not currently supported.\n", output_state);
+    fatal(MYNAME ": writing output for state \"%s\" is not currently supported.\n", output_state);
   }
 }
 
index c1a592e60729535d9b7a62fb6ffb122be1af7c36..5900485430fede581b65001f298855db2f1361b8 100644 (file)
@@ -630,7 +630,7 @@ void TrackFilter::trackfilter_synth()
         }
         if (opt_speed) {
           if (last_speed_time.msecsTo(wpt->GetCreationTime()) != 0) {
-            // If we have mutliple points with the same time and
+            // If we have multiple points with the same time and
             // we use the pair of points about which the time ticks then we will
             // underestimate the distance and compute low speeds on average.
             // Therefore, if we have multiple points with the same time use the
@@ -965,7 +965,7 @@ void TrackFilter::init()
                 opt_move || opt_fix || opt_speed ||
                 (trackfilter_opt_count() == 0) /* do pack by default */
               );
-  /* in case of a formated title we also need valid timestamps */
+  /* in case of a formatted title we also need valid timestamps */
   if ((opt_title != nullptr) && (strchr(opt_title, '%') != nullptr)) {
     need_time = true;
   }
index bf1e9383f42ea08771ff20e38713dc125fe27e6b..c4dd8182f30e5096640bdc91d517b5a67aa2dd29 100644 (file)
--- a/unicsv.cc
+++ b/unicsv.cc
@@ -409,7 +409,7 @@ unicsv_parse_time(const char* str, int* usec, time_t* date)
   double us;
   char sep[2];
 
-  /* If we have somethine we're pretty sure is a date, parse that
+  /* If we have something we're pretty sure is a date, parse that
    * first, skip over it, and pass that back to the caller)
    */
   time_t ldate = unicsv_parse_date(str, &consumed);
@@ -1225,7 +1225,7 @@ static void
 unicsv_fatal_outside(const Waypoint* wpt)
 {
   *fout << "#####\n";
-  fatal(MYNAME ": %s (%s) is outside of convertable area of grid \"%s\"!\n",
+  fatal(MYNAME ": %s (%s) is outside of convertible area of grid \"%s\"!\n",
         wpt->shortname.isEmpty() ? "Waypoint" : qPrintable(wpt->shortname),
         pretty_deg_format(wpt->latitude, wpt->longitude, 'd', nullptr, 0),
         gt_get_mps_grid_longname(unicsv_grid_idx, MYNAME));
diff --git a/util.cc b/util.cc
index c892d6a0263f76567485555da65b133b4d844829..f080a353f008b1a863b3fa0a14a4ba09d4368c8c 100644 (file)
--- a/util.cc
+++ b/util.cc
@@ -220,9 +220,9 @@ QString ugetenv(const char* env_var) {
  * Allocate a string using a format list with optional arguments
  * Returns -1 on error.
  * If return value is anything else, *strp will be populated with an
- * allocated string containging the formatted buffer.
+ * allocated string containing the formatted buffer.
  *
- * Freeing that is the responsbility of the caller.
+ * Freeing that is the responsibility of the caller.
  */
 
 int
@@ -310,7 +310,7 @@ xvasprintf(char** strp, const char* fmt, va_list ap)
     } else if (outsize == bufsize - 1) {
       /* This is ambiguous. May mean that the output string
        * exactly fits, but on some systems the output string
-       * may have been trucated. We can't tell.
+       * may have been truncated. We can't tell.
        * Just double the buffer size for next time.
        */
       nextsize = bufsize * 2;
@@ -798,7 +798,7 @@ get_cache_icon(const Waypoint* waypointp)
     return "Multi-Cache";
   case gt_event:
     return "Event Cache";
-  case gt_suprise:
+  case gt_surprise:
     return "Unknown Cache";
   case gt_webcam:
     return "Webcam Cache";
@@ -1742,7 +1742,7 @@ list_codecs()
       maxlen = codec->name().size();
     }
   }
-  info << "Avaialble Codecs:" << endl;
+  info << "Available Codecs:" << endl;
   info << qSetFieldWidth(8) << "MIBenum" << qSetFieldWidth(maxlen+1) << "Name" << qSetFieldWidth(0) << "Aliases" << endl;
   for (auto mib : mibs) {
     auto codec = QTextCodec::codecForMib(mib);
diff --git a/v900.cc b/v900.cc
index 9af0e33fd3dd01a87b8b279bd86457a12bda0847..18e76adcf7db477c20bd198b1c02a1ce9b81fb70 100644 (file)
--- a/v900.cc
+++ b/v900.cc
  FILE FORMAT INFO
 =================
 
-File has csv extention, and is somewhat csv like creature...
+File has csv extension, and is somewhat csv like creature...
 All lines end with \r\n
 First line is a header line. It contains no nulls.
 Following lines are record lines. They are comma separated, but fields always
-have the exact same length (per field), and therfore, the commas are always
+have the exact same length (per field), and therefore, the commas are always
 at the exact same position on the line. Fields are padded with nulls, in case
 they have shorter value then the fixed field length.
 Two modes are available: basic and advanced.
diff --git a/vecs.cc b/vecs.cc
index 33e3c6df6e268a6103e0329f3e632b052f9c850c..6ec8a8816751012cbc15fdb5ba3efa4fbccb8971 100644 (file)
--- a/vecs.cc
+++ b/vecs.cc
@@ -1475,7 +1475,7 @@ sort_and_unify_vecs(int* ctp)
     svp[i]->name = svec->name;
     svp[i]->vec = (ff_vecs_t*) xmalloc(sizeof(*svp[i]->vec));
     svp[i]->extensions = xcsv_file.extension;
-    *svp[i]->vec = *vec_list[0].vec; /* Interits xcsv opts */
+    *svp[i]->vec = *vec_list[0].vec; /* Inherits xcsv opts */
     /* Reset file type to inherit ff_type from xcsv for everything
      * except the xcsv format itself, which we leave as "internal"
      */
index 2e154becc0e2e395fdaa571214a1a22852622e2a..68e5bf9d47c6f51796fc6a3c53dc1894c5a0c7f7 100644 (file)
--- a/waypt.cc
+++ b/waypt.cc
@@ -62,7 +62,7 @@ void update_common_traits(const Waypoint* wpt)
 {
   /* This is a bit tacky, but it allows a hint whether we've seen
    * this data or not in the life cycle of this run.   Of course,
-   * the caches could have been filtered out of existance and not
+   * the caches could have been filtered out of existence and not
    * all waypoints may have this and a few other pitfalls, but it's
    * an easy and fast test here.
    */
@@ -142,7 +142,7 @@ waypt_bounds_valid(bounds* bounds)
 }
 
 /*
- * Recompund bounding box based on new position point.
+ * Recompute bounding box based on new position point.
  */
 void
 waypt_add_to_bounds(bounds* bounds, const Waypoint* waypointp)
@@ -473,7 +473,7 @@ Waypoint::Waypoint(const Waypoint& other) :
   session(other.session),
   extra_data(other.extra_data)
 {
-  // deep copy geocache data unless it is the specail static empty_gc_data.
+  // deep copy geocache data unless it is the special static empty_gc_data.
   if (other.gc_data != &Waypoint::empty_gc_data) {
     gc_data = new geocache_data(*other.gc_data);
   }
@@ -526,7 +526,7 @@ Waypoint& Waypoint::operator=(const Waypoint& rhs)
     fs = rhs.fs;
     session = rhs.session;
     extra_data = rhs.extra_data;
-    // deep copy geocache data unless it is the specail static empty_gc_data.
+    // deep copy geocache data unless it is the special static empty_gc_data.
     if (rhs.gc_data != &Waypoint::empty_gc_data) {
       gc_data = new geocache_data(*rhs.gc_data);
     }
diff --git a/xcsv.cc b/xcsv.cc
index 1d6dbb19e6ae000185ec5f19fedf620716a6f042..e6cd5bee326b78c90d1223d6bc6b7521d58750a3 100644 (file)
--- a/xcsv.cc
+++ b/xcsv.cc
@@ -322,7 +322,7 @@ xcsv_get_char_from_constant_table(const QString& key)
   if (substitutions.contains(key)) {
     return substitutions[key];
   }
-  // No substition found? Just return original.
+  // No substitution found? Just return original.
   return key;
 }
 
@@ -609,7 +609,7 @@ xcsv_parse_val(const char* s, Waypoint* wpt, const field_map& fmp,
     /* ANYNAME -- Ignore -- this is output magic. */
     break;
   case XT_INDEX:
-    /* IGNORE -- Calculated Sequence # For Ouput*/
+    /* IGNORE -- Calculated Sequence # For Output*/
     break;
   case XT_SHORTNAME:
     wpt->shortname = csv_stringtrim(s, enclosure);
@@ -1354,12 +1354,12 @@ xcsv_waypt_pr(const Waypoint* wpt)
                fabs(lon));
       break;
     case XT_LON_INT32DEG:
-      /* longitudee as an integer offset from 0 degrees */
+      /* longitude as an integer offset from 0 degrees */
       buff = QString().sprintf(fmp.printfc.constData(),
                 dec_to_intdeg(lon));
       break;
     case XT_LON_DDMMDIR:
-      /* longidute as (degrees * 100) + decimal minutes, with W/E after it*/
+      /* longitude as (degrees * 100) + decimal minutes, with W/E after it*/
       buff = dec_to_human(fmp.printfc.constData(), "WE", degrees2ddmm(lon));
       break;
     case XT_LON_HUMAN_READABLE:
@@ -1887,7 +1887,7 @@ xcsv_parse_style_line(QString line)
     if (tokens[0] == "INTERNAL") {
       xcsv_file.type = ff_type_internal;
     }
-      // this is almost inconcievable...
+      // this is almost inconceivable...
     if (tokens[0] == "SERIAL") {
       xcsv_file.type = ff_type_serial;
     }
@@ -1975,7 +1975,7 @@ xcsv_parse_style_line(QString line)
       //
   if (op == "OFIELD") {
     unsigned options = 0;
-      // Note: simplifieid() has to run after split().
+      // Note: simplified() has to run after split().
     if (tokens.size() < 3) {
       Fatal() << "Invalid OFIELD line: " << tokenstr;
     }
index 9bd9ae91e4cb251527c363caaf88d6a5a9125def..d832fee499421b0fbaa66923ae8548c0f8f09359 100644 (file)
@@ -111,7 +111,7 @@ xml_run_parser(QXmlStreamReader& reader)
       }
       if (codec == nullptr) {
         // According to http://www.opentag.com/xfaq_enc.htm#enc_default , we
-        // should assume UTF-8 in absense of other informations. Users can
+        // should assume UTF-8 in absence of other information. Users can
         // EASILY override this with xml_init().
         codec = QTextCodec::codecForName("UTF-8");
       }
diff --git a/xol.cc b/xol.cc
index c1100dde5377b2f4959cfc3f51599efe1a4b5ccf..12fe7ee7f50a9805fe7e1eeac5d4321810528f29 100644 (file)
--- a/xol.cc
+++ b/xol.cc
@@ -145,7 +145,7 @@ static void xol_rd_deinit() { xml_deinit(); }
 /* writer */
 
 static void xol_fatal_outside(const Waypoint* wpt) {
-  fatal(MYNAME ": %s (%s) is outside of convertable area \"%s\"!\n",
+  fatal(MYNAME ": %s (%s) is outside of convertible area \"%s\"!\n",
         wpt->shortname.isEmpty() ? "Waypoint" : qPrintable(wpt->shortname),
         pretty_deg_format(wpt->latitude, wpt->longitude, 'd', nullptr, 0),
         gt_get_mps_grid_longname(grid_swiss, MYNAME));
@@ -273,7 +273,7 @@ static void xol_write() {
                                   (all_bounds.min_lon + all_bounds.max_lon) / 2,
                                   &x, &y)) {
     fatal(MYNAME
-          ": At least one point is outside of convertable area \"%s\"!\n",
+          ": At least one point is outside of convertible area \"%s\"!\n",
           gt_get_mps_grid_longname(grid_swiss, MYNAME));
   }
diff --git a/igo8.cc b/igo8.cc
index c89a4a0a8c590476b207aa6d013378a995ff7395..28524325d2e60a873df601f20565c23f96e80abe 100644 (file)
--- a/igo8.cc
+++ b/igo8.cc
@@ -273,7 +273,7 @@ static unsigned int print_unicode(char* dst, const unsigned int dst_max_length,
 /* 2008/06/24, O.K.: Use CET library for ascii-> unicode 2 converter */
 // 2008/07/25, Dustin: Slight fix to make sure that we always null terminate the
 //                     string, validate that the use of the CET library provides
-//                     conmforming output, remove my old junk converter code.
+//                     conforming output, remove my old junk converter code.
 
 static unsigned int ascii_to_unicode_2(char* dst, const unsigned int dst_max_length, const char* src)
 {
index dfa10edfb246bf9b5513395adb420fa7c5d5a4b1..990323463fceabfe6f2719f95317aadef1383c65 100644 (file)
@@ -1,5 +1,5 @@
 /* This file is machine-generated from the contents of style/ */
-/* by mkstyle.sh.   Editing it by hand is an exeedingly bad idea. */
+/* by mkstyle.sh.   Editing it by hand is an exceedingly bad idea. */
 
 #include "defs.h"
 #if CSVFMTS_ENABLED
@@ -267,7 +267,7 @@ static char fugawi[] =
   "PROLOGUE \\# Waypoint name\n"
   "PROLOGUE \\# Waypoint comment\n"
   "PROLOGUE \\# Waypoint description\n"
-  "PROLOGUE \\# Latitude in Degree and decimals (soutern hemisphere has neg. degrees)\n"
+  "PROLOGUE \\# Latitude in Degree and decimals (southern hemisphere has neg. degrees)\n"
   "PROLOGUE \\# Longitude in degree and decimals (neg. numbers: west of Greenwich)\n"
   "PROLOGUE \\# Height in meters [optional when importing, always present when exporting: Date (GMT) as ISO YYYYMMDD, Time of the day relative to the date as HHMMSS\n"
 
@@ -1471,7 +1471,7 @@ static char xmapwpt[] =
 
   "#\n"
   "#\n"
-  "# FILE LAYOUT DEFINITIIONS:\n"
+  "# FILE LAYOUT DEFINITIONS:\n"
   "#\n"
   "FIELD_DELIMITER             COLON\n"
   "RECORD_DELIMITER    NEWLINE\n"
index 619bb136385a979fa3b0137132c6b9dbb37a7cf4..9f3258e1c9a6d85c8e180df7c18c99ebc78cf8ef 100644 (file)
@@ -313,7 +313,7 @@ to_itracku_data_record(const Waypoint* wp, itracku_data_record* d)
        Tries to initialize an itracku device attached to
        serial port fd. fd must already be opened.
 
-       Returns gbser_OK if the initialization is sucessful, a
+       Returns gbser_OK if the initialization is successful, a
        non-zero integer otherwise.
 */
 static int
index e8a63675933664afc00e8ee4e88a5ddaa08c77c5..9baebaddb25487ba26fa17403d68983ee3c2d127 100644 (file)
@@ -523,7 +523,7 @@ static void GPS_A001(GPS_PPacket& packet)
           break;
 
           /*
-           * Observered on Quest 3.0, 27xx, 27x, 29x.
+           * Observed on Quest 3.0, 27xx, 27x, 29x.
            */
         case 120:
           gps_category_type = data;
@@ -2423,7 +2423,7 @@ static void GPS_D108_Send(UC* data, GPS_PWay way, int32* len)
 ** @param [w] len [int32 *] packet length
 **
 ** @return [void]
-** D109's and D110's are so simlar, we handle themw with the same code.
+** D109's and D110's are so similar, we handle them with the same code.
 ************************************************************************/
 static void GPS_D109_Send(UC* data, GPS_PWay way, int32* len, int protoid)
 {
@@ -4024,7 +4024,7 @@ int32 GPS_A300_Send(const char* port, GPS_PTrack* trk, int32 n)
     }
 
     if (!GPS_Get_Ack(fd, &tra, &rec)) {
-      GPS_Error("A300_Send: Pid_Trk_Data not acknowledgedn");
+      GPS_Error("A300_Send: Pid_Trk_Data not acknowledged");
       return FRAMING_ERROR;
     }
   }
@@ -4906,7 +4906,7 @@ int32 GPS_A400_Send(const char* port, GPS_PWay* way, int32 n)
     return gps_errno;
   }
   if (!GPS_Get_Ack(fd, &tra, &rec)) {
-    GPS_Error("A400_Send: Prx start data not acknowledgedn");
+    GPS_Error("A400_Send: Prx start data not acknowledged");
     return FRAMING_ERROR;
   }
 
@@ -5990,7 +5990,7 @@ int32 GPS_A700_Get(const char* port, double* lat, double* lon)
 **
 ** @param [r] port [const char *] serial port
 ** @param [r] lat [double] latitude  (deg)
-** @param [r] lon [double] longitute (deg)
+** @param [r] lon [double] longitude (deg)
 **
 ** @return [int32] success
 ************************************************************************/
@@ -6856,7 +6856,7 @@ int32 GPS_A1007_Send(const char*,
       GPS_D1007_Send(data,clp[i],&len);
       break;
     default:
-      GPS_Error("A1007_Send: Unknown couse_lap type %d\n",
+      GPS_Error("A1007_Send: Unknown course_lap type %d\n",
                 gps_course_lap_type);
       return PROTOCOL_ERROR;
     }
@@ -7127,7 +7127,7 @@ int32 GPS_A1008_Send(const char*,
       GPS_D1012_Send(data,cpt[i],&len);
       break;
     default:
-      GPS_Error("GPS_A1008_Send: Unknown couse_point type %d\n",
+      GPS_Error("GPS_A1008_Send: Unknown course_point type %d\n",
                 gps_course_point_type);
       return PROTOCOL_ERROR;
     }
index f9e9b17ab6bcb4b75f16e1e9d32adbd70e4efc67..7cfca874eb2d45c96db0e2557f6b7360a97664ef 100644 (file)
@@ -94,7 +94,7 @@
   A1005  Workout Limits Transfer Protocol
        Capability A1005: D1005
   */
-  /* Unimplemted and Undocumented, as listed from the following device/sw:
+  /* Unimplemented and Undocumented, as listed from the following device/sw:
        GF305 3.70
 
   Capability A601: D601
index cde3bbae2b6782563520b67071830ec06e2794f3..547c4487a124a6efb460883a1af8960d6eb2c2b6 100644 (file)
@@ -935,7 +935,7 @@ static uint32 Unique_Track_Index(GPS_PCourse* crs, int n_crs)
 ** Calculate lap data totals from individual track points. Also
 ** generates time stamps for track points if they don't have
 ** time stamps yet (using an arbitrary speed of 10 km/h which is
** currently hardcoded. This is required so that couse points can
 ** refer to track points and identify them uniquely.
 **
 ** @param [w] clp [GPS_PCourse_Lap] course lap to be calculated
index a354a947395505b51e74564644c4b58b5489ec44..7362f8b6d9369df03c9608b290f11fbcdf71588c 100644 (file)
@@ -41,8 +41,8 @@
 #define GARMIN_VID 0x91e
 
 /* This is very sensitive to timing; libusb and/or the unit is kind of
- * sloppy about not obeying packet boundries.  If this is too high, the
- * multiple packets responding to the device inquriy will be glommed into
+ * sloppy about not obeying packet boundaries.  If this is too high, the
+ * multiple packets responding to the device inquiry will be glommed into
  * one packet and we'll misparse them.  If it's too low, we'll get partially
  * satisfied reads.  It turns out this isn't terrible because we still end
  * up with DLE boundings and the upper layers (which are used to doing frame
@@ -194,14 +194,14 @@ gusb_atexit_teardown()
  * remove this.
  *
  * 9/2008 But wait, there's more.   The very toggle reset that we *had* to
- * implement in 2006 to make non-Windows OSes work actually locks up verion
+ * implement in 2006 to make non-Windows OSes work actually locks up version
  * 2.70 of the Venture HC.   On that model, the second product request
  * (you know, the one that we *use*, locks that device's protocol stack
  * after the RET2INTR that immediately follows the REQBLK (and why is it
- * telling us to go into bulk mode followed by an immeidate EOF, anyway?)
+ * telling us to go into bulk mode followed by an immediate EOF, anyway?)
  * that follows the request for product ID.   100% reproducible on Mac and
  * Linux.    Of course, we don't see this on the Windows system because
- * we don't have to jump through hooops to clear the spec-violating out
+ * we don't have to jump through hoops to clear the spec-violating out
  * of state toggles there because those systems see only one configuration
  * set ever.
  *
@@ -250,7 +250,7 @@ gusb_reset_toggles()
   /*
    * Now that the bulk out and intr in packets are good, we send
    * a product ID.    On devices that respond totally on the intr
-   * pipe, this does nothing interesting, but on devices that respon
+   * pipe, this does nothing interesting, but on devices that respond
    * on the bulk pipe this will reset the toggles on the bulk in.
    */
 
@@ -371,7 +371,7 @@ garmin_usb_start(struct usb_device* dev, libusb_unit_data* lud)
   if (gusb_intr_in_ep && gusb_bulk_in_ep && gusb_bulk_out_ep) {
     lud->product_id = gusb_reset_toggles();
     switch (lud->product_id) {
-      // Search for "Venture HC" for more on this siliness..
+      // Search for "Venture HC" for more on this silliness..
       // It's a case instead of an 'if' because I have a
       // feeling there are more affected models either
       // on the market or on the way.
index 35c71c8756e35bc666a4659dda7e14e06b91e97b..75a0a61cbffa22440f836dbd3fca4c069354f627 100644 (file)
@@ -1115,7 +1115,7 @@ int32 GPS_Math_WGS84_To_ICS_EN(double lat, double lon, double* E,
 /* @GPS_Math_ICS_EN_To_WGS84 *****************************************
 **
 ** Convert WGS84 latitude and longitude to
-** Israeli Oldl Grid Eastings and Northings
+** Israeli Old Grid Eastings and Northings
 **
 ** @param [r] E [double] ICS easting (metres)
 ** @param [r] N [double] ICS northing (metres)
@@ -2502,7 +2502,7 @@ void GPS_Math_UTM_EN_to_LatLon(int ReferenceEllipsoid,
 //East Longitudes are positive, West longitudes are negative.
 //North latitudes are positive, South latitudes are negative
 //Lat and Long are in decimal degrees.
-//based on code witten by Chuck Gantz- chuck.gantz@globalstar.com
+//based on code written by Chuck Gantz- chuck.gantz@globalstar.com
 //found at http://www.gpsy.com/gpsinfo/geotoutm/index.html
 
   double k0 = 0.9996;
index 4a3e73943ab2011a738f5bad498aa4936fa69f90..84f672c6f5e8db79eb24990e9f2b486eeda1ef03 100644 (file)
@@ -128,7 +128,7 @@ int32 GPS_Rqst_Send_Position(gpsdevh* fd, double lat, double lon)
 **
 ** @param [r] fd [int32] file descriptor
 ** @param [r] lat [double] latitude  (deg)
-** @param [r] lon [double] longitute (deg)
+** @param [r] lon [double] longitude (deg)
 **
 ** @return [int32] success
 ************************************************************************/
index 36de12475c0a8d328fcf84256d14955bde1d407e..351538d52f558bf49e61d800d45fbb4e859c4aa5 100644 (file)
@@ -649,7 +649,7 @@ int32 GPS_Serial_Set_Baud_Rate(gpsdevh* fd, int br)
     return gps_errno;
   }
 
-  // Acnowledge new speed
+  // Acknowledge new speed
   if (!GPS_Send_Ack(fd, &tra, &rec)) {
     return gps_errno;
   }
index f85e555fd1a327a4e26422de3b5d7973b6fc08eb..225f747d6a2a440ac8fffd0931aa9d9e7d9b59c0 100644 (file)
@@ -228,7 +228,7 @@ gusb_id_unit(garmin_unit_info_t* gu)
       gu->unit_version = le_read16(iresp.gusb_pkt.databuf+2);
     }
     /*
-     * My goodnesss, this is fragile.  During command syncup,
+     * My goodness, this is fragile.  During command syncup,
      * we need to know if we're at the end.  The 0xfd packet
      * is promised by Garmin engineering to be the last.
      */
index d3a19842007925e8978fdd44496f4fdd914e3cc5..e2d9ba05265e3afb0305384df018ea1989836fff 100644 (file)
@@ -276,7 +276,7 @@ uint32 GPS_Util_Get_Uint(const UC* s)
 
 /* @func GPS_Util_Put_Uint ********************************************
 **
-** Put an unisgned int to a string
+** Put an unsigned int to a string
 **
 ** @param [w] s [UC *] string to write to
 ** @param [r] v [const uint32] unsigned int to write
@@ -685,7 +685,7 @@ void GPS_Enable_Diagnose()
 
 
 
-/* @func GPS_Disble_Diagnose ***********************************************
+/* @func GPS_Disable_Diagnose ***********************************************
 **
 ** Disable diagnosis mode
 **
@@ -935,7 +935,7 @@ static uint32 Unique_Track_Index(GPS_PCourse* crs, int n_crs)
 ** generates time stamps for track points if they don't have
 ** time stamps yet (using an arbitrary speed of 10 km/h which is
-** currently hardcoded. This is required so that couse points can
+** currently hardcoded. This is required so that course points can
 ** refer to track points and identify them uniquely.
 **